;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "clojure-mode" "20260615.1407"
  "Major mode for Clojure code."
  '((emacs "27.1"))
  :url "https://github.com/clojure-emacs/clojure-mode"
  :commit "762674d956a4e861f46711a00921b159f96792c0"
  :revdesc "762674d956a4"
  :keywords '("languages" "clojure" "clojurescript" "lisp")
  :authors '(("Jeffrey Chu" . "jochu0@gmail.com")
             ("Lennart Staflin" . "lenst@lysator.liu.se")
             ("Phil Hagelberg" . "technomancy@gmail.com")
             ("Bozhidar Batsov" . "bozhidar@batsov.dev")
             ("Artur Malabarba" . "bruce.connor.am@gmail.com")
             ("Magnar Sveen" . "magnars@gmail.com"))
  :maintainers '(("Bozhidar Batsov" . "bozhidar@batsov.dev")))
